# SERM

SERM is an open-source library for evaluating how easy-to-read a text is. It supports a wide variety of indexes and allows the user to easily combine them. 


## Features

* Several indexes are provided.